# commitizen-cz-fogoprobr

Commitizen personalizado por melattofogo

## Uso

Listar commitizen instalados

```
cz ls
```

*Commit* de *code* em *stage*

```
cz --name cz_fogoprobr commit
```

Alternativamente, definindo o commitizen do projeto em um arquivo ```.cz``` do projeto

```
(echo [commitizen] & echo.name = cz_fogoprobr) >> .cz
cz commit
```

## Requisitos

- [commitizen](https://github.com/commitizen-tools/commitizen) ```2.21.2```

## Autor
Joao Fogo (melatto.fogo@live.com)
